Index: trunk/xpressme_integration_kit/wp-content/plugins/xpressme/include/update_xpress.php
===================================================================
--- trunk/xpressme_integration_kit/wp-content/plugins/xpressme/include/update_xpress.php	(revision 759)
+++ trunk/xpressme_integration_kit/wp-content/plugins/xpressme/include/update_xpress.php	(revision 775)
@@ -33,12 +33,15 @@
  */
 function update_xpress($from, $to) {
-	global $wp_filesystem, $_old_xpress_files, $wpdb;
+	global $wp_filesystem, $_old_xpress_files, $wpdb, $modInfo;
 	show_message( __('Disable overwrite of wp-config.php...', 'xpressme') );
-	// remove wp-config.php from the new version into place.
-	$wp_config = $from . 'wp-config.php';
-	if ( !$wp_filesystem->delete($wp_config, true)){
-		return new WP_Error('delete_failed', $this->strings['delete_failed']);
+	$mod_ver = $modInfo->get_module_version();
+	// Rewrite wp-config.php when update it to Ver.3 from Ver.2. 
+	if (version_compare($mod_ver, '3.0', '>=')){
+		// remove wp-config.php from the new version into place.
+		$wp_config = $from . 'wp-config.php';
+		if ( !$wp_filesystem->delete($wp_config, true)){
+			return new WP_Error('delete_failed', $this->strings['delete_failed']);
+		}
 	}
-
 	// Copy new versions of XPressME Integration Kit files into place.
 	show_message( __('Copy new versions of XPressME Integration Kit files into place...', 'xpressme') );
